@@ -249,7 +249,7 @@ class App(object):
                  keymap='default', debug=False, verbose=False,
                  disable_sync=False, disable_background_sync=False,
                  fetch_missing_refs=False,
-                 path=config.DEFAULT_CONFIG_PATH):
+                 path=None):
         self.server = server
         self.config = config.Config(server, palette, keymap, path)
         if debug:
@@ -374,12 +374,12 @@ class App(object):
             try:
                 s, addr = self.socket.accept()
                 self.log.debug("Accepted socket connection %s" % (s,))
-                buf = ''
+                buf = b''
                 while True:
                     buf += s.recv(1)
-                    if buf[-1] == '\n':
+                    if buf[-1] == 10:
                         break
-                buf = buf.strip()
+                buf = buf.decode('utf8').strip()
                 self.log.debug("Received %s from socket" % (buf,))
                 s.close()
                 parts = buf.split()
@@ -401,6 +401,11 @@ class App(object):
         self.clearInputBuffer()
         self.frame.body = widget
 
+    def getPreviousScreen(self):
+        if not self.screens:
+            return None
+        return self.screens[-1]
+
     def backScreen(self, target_widget=None):
         if not self.screens:
             return
@@ -874,14 +879,13 @@ class OpenChangeAction(argparse.Action):
 
         s = socket.socket(socket.AF_UNIX, socket.SOCK_STREAM)
         s.connect(cf.socket_path)
-        s.sendall('open %s\n' % url)
+        s.sendall(('open %s\n' % url).encode('utf8'))
         sys.exit(0)
 
 def main():
     parser = argparse.ArgumentParser(
         description='Console client for Gerrit Code Review.')
     parser.add_argument('-c', dest='path',
-                        default=config.DEFAULT_CONFIG_PATH,
                         help='path to config file')
     parser.add_argument('-v', dest='verbose', action='store_true',
                         help='enable more verbose logging')
