@@ -17,6 +17,7 @@ import collections
 import getpass
 import os
 import re
+import sys
 try:
     import ordereddict
 except:
@@ -35,7 +36,8 @@ try:
 except AttributeError:
     OrderedDict = ordereddict.OrderedDict
 
-DEFAULT_CONFIG_PATH='~/.gertty.yaml'
+DEFAULT_CONFIG_PATH = '~/.config/gertty/gertty.yaml'
+FALLBACK_CONFIG_PATH = '~/.gertty.yaml'
 
 class ConfigSchema(object):
     server = {v.Required('name'): str,
@@ -48,6 +50,7 @@ class ConfigSchema(object):
               v.Required('git-root'): str,
               'git-url': str,
               'log-file': str,
+              'lock-file': str,
               'socket': str,
               'auth-type': v.Any('basic', 'digest', 'form'),
               }
@@ -92,6 +95,7 @@ class ConfigSchema(object):
                           v.Required('value'): int}
 
     reviewkey = {v.Required('approvals'): [reviewkey_approval],
+                 v.Optional('message'): str,
                  'submit': bool,
                  v.Required('key'): str}
 
@@ -109,6 +113,11 @@ class ConfigSchema(object):
 
     keymaps = [keymap]
 
+    thresholds = [int, int, int, int, int, int, int, int]
+    size_column = {v.Required('type'): v.Any('graph', 'split-graph', 'number',
+                                             'disabled', None),
+                   v.Optional('thresholds'): thresholds}
+
     def getSchema(self, data):
         schema = v.Schema({v.Required('servers'): self.servers,
                            'palettes': self.palettes,
@@ -125,21 +134,19 @@ class ConfigSchema(object):
                            'display-times-in-utc': bool,
                            'handle-mouse': bool,
                            'breadcrumbs': bool,
+                           'close-change-on-review': bool,
                            'change-list-options': self.change_list_options,
                            'expire-age': str,
+                           'size-column': self.size_column,
                            })
         return schema
 
 class Config(object):
     def __init__(self, server=None, palette='default', keymap='default',
-                 path=DEFAULT_CONFIG_PATH):
-        self.path = os.path.expanduser(path)
+                 path=None):
+        self.path = self.verifyConfigFile(path)
 
-        if not os.path.exists(self.path):
-            self.printSample()
-            exit(1)
-
-        self.config = yaml.load(open(self.path))
+        self.config = yaml.safe_load(open(self.path))
         schema = ConfigSchema().getSchema(self.config)
         schema(self.config)
         server = self.getServer(server)
@@ -164,7 +171,7 @@ class Config(object):
                     "Error: Config file '{}' contains a password and does "
                     "not have permissions set to 0600.\n"
                     "Permissions are: {}".format(self.path, oct(mode)))
-                exit(1)
+                sys.exit(1)
         self.auth_type = server.get('auth-type', 'digest')
         self.verify_ssl = server.get('verify-ssl', True)
         if not self.verify_ssl:
@@ -239,6 +246,7 @@ class Config(object):
         self.thread_changes = self.config.get('thread-changes', True)
         self.utc = self.config.get('display-times-in-utc', False)
         self.breadcrumbs = self.config.get('breadcrumbs', True)
+        self.close_change_on_review = self.config.get('close-change-on-review', False)
         self.handle_mouse = self.config.get('handle-mouse', True)
 
         change_list_options = self.config.get('change-list-options', {})
@@ -248,6 +256,24 @@ class Config(object):
 
         self.expire_age = self.config.get('expire-age', '2 months')
 
+        self.size_column = self.config.get('size-column', {})
+        self.size_column['type'] = self.size_column.get('type', 'graph')
+        if self.size_column['type'] == 'graph':
+            self.size_column['thresholds'] = self.size_column.get('thresholds',
+                [1, 10, 100, 1000])
+        else:
+            self.size_column['thresholds'] = self.size_column.get('thresholds',
+                [1, 10, 100, 200, 400, 600, 800, 1000])
+
+    def verifyConfigFile(self, path):
+        for checkpath in [ path, DEFAULT_CONFIG_PATH, FALLBACK_CONFIG_PATH ]:
+            if checkpath is not None:
+                expandedpath = os.path.expanduser(checkpath)
+                if os.path.exists(expandedpath):
+                    return expandedpath
+        self.printSample()
+        sys.exit(1)
+
     def getServer(self, name=None):
         for server in self.config['servers']:
             if name is None or name == server['name']:
