@@ -1,3 +1,4 @@
+# -*- coding: utf-8 -*-
 # Copyright 2014 OpenStack Foundation
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
@@ -13,9 +14,9 @@
 # under the License.
 
 # Test changes:
-# https://review.openstack.org/275862
-# https://review.openstack.org/119302
-# https://review.openstack.org/133550
+# https://review.opendev.org/275862
+# https://review.opendev.org/119302
+# https://review.opendev.org/133550
 
 import datetime
 import logging
@@ -173,6 +174,8 @@ class DiffChangedChunk(DiffChunk):
     context = False
 
 class DiffFile(object):
+    log = logging.getLogger('gertty.gitrepo')
+
     def __init__(self):
         self.newname = 'Unknown File'
         self.oldname = 'Unknown File'
@@ -187,9 +190,12 @@ class DiffFile(object):
     def finalize(self):
         if not self.current_chunk:
             return
+        oldlines = [(n, d, self.expand_tabs(l)) for (n, d, l)
+                        in self.current_chunk.oldlines]
+        newlines = [(n, d, self.expand_tabs(l)) for (n, d, l)
+                        in self.current_chunk.newlines]
         self.current_chunk.lines = list(
-                six.moves.zip(self.current_chunk.oldlines,
-                              self.current_chunk.newlines))
+                six.moves.zip(oldlines, newlines))
         if not self.chunks:
             self.current_chunk.first = True
         else:
@@ -199,6 +205,27 @@ class DiffFile(object):
         self.chunks.append(self.current_chunk)
         self.current_chunk = None
 
+    def expand_tabs(self, l, tabstop = 8):
+        offset = { 'start': 0, 'prevstart': 0 }
+        def replace(match):
+            offset['start'] += match.start(0) - offset['prevstart']
+            offset['prevstart'] = match.start(0)
+            cnt = tabstop - offset['start'] % tabstop - 1
+            offset['start'] += cnt
+            return "»" + " " * cnt
+
+        try:
+            if isinstance(l, six.string_types):
+                return re.sub(r'\t', replace, l)
+            elif isinstance(l, list):
+                return [self.expand_tabs(e) for e in l]
+            else:
+                (a, b) = l
+                return (a, re.sub(r'\t', replace, b))
+        except Exception:
+            self.log.exception("Error expanding tabs")
+            return l
+
     def addDiffLines(self, old, new):
         if (self.current_chunk and
             not isinstance(self.current_chunk, DiffChangedChunk)):
@@ -259,15 +286,17 @@ class Repo(object):
                 raise GitCloneError("No URL available for git clone")
             git.Repo.clone_from(self.url, self.path)
 
-    def hasCommit(self, sha):
+    def checkCommits(self, shas):
+        invalid = set()
         repo = git.Repo(self.path)
-        try:
-            repo.commit(sha)
-        except gitdb.exc.BadObject:
-            return False
-        except ValueError:
-            return False
-        return True
+        for sha in shas:
+            try:
+                repo.commit(sha)
+            except gitdb.exc.BadObject:
+                invalid.add(sha)
+            except ValueError:
+                invalid.add(sha)
+        return invalid
 
     def fetch(self, url, refspec):
         repo = git.Repo(self.path)
@@ -512,7 +541,10 @@ class Repo(object):
                 f.old_lineno = 1
                 f.new_lineno = 1
                 for line in blob.data_stream.read().splitlines():
-                    f.addContextLine(line)
+                    if isinstance(line, six.string_types):
+                        f.addContextLine(line)
+                    else:
+                        f.addContextLine(line.decode('utf8'))
             f.finalize()
         return files
 
@@ -529,7 +561,10 @@ class Repo(object):
         except KeyError:
             return None
         for line in blob.data_stream.read().splitlines():
-            f.addContextLine(line)
+            if isinstance(line, six.string_types):
+                f.addContextLine(line)
+            else:
+                f.addContextLine(line.decode('utf8'))
         f.finalize()
         return f
 
