@@ -91,8 +91,8 @@ DEFAULT_KEYMAP = {
     CURSOR_DOWN: 'down',
     CURSOR_LEFT: 'left',
     CURSOR_RIGHT: 'right',
-    CURSOR_PAGE_UP: 'page up',
-    CURSOR_PAGE_DOWN: 'page down',
+    CURSOR_PAGE_UP: ['page up', 'meta v'],
+    CURSOR_PAGE_DOWN: ['page down', 'ctrl v'],
     CURSOR_MAX_LEFT: ['home', 'ctrl a'],
     CURSOR_MAX_RIGHT: ['end', 'ctrl e'],
     ACTIVATE: 'enter',
