@@ -18,6 +18,7 @@ DEFAULT_PALETTE={
     'error': ['light red', 'dark blue'],
     'table-header': ['white,bold', ''],
     'filename': ['light cyan', ''],
+    'filename-inline-comment': ['dark cyan', ''],
     'focused-filename': ['light cyan,standout', ''],
     'positive-label': ['dark green', ''],
     'negative-label': ['dark red', ''],
@@ -98,6 +99,22 @@ DEFAULT_PALETTE={
     'added-removed-graph': ['dark green', 'dark red'],
     'focused-added-graph': ['default,standout', 'dark green'],
     'focused-removed-graph': ['default,standout', 'dark red'],
+    'line-count-threshold-1': ['light green', ''],
+    'focused-line-count-threshold-1': ['light green,standout', ''],
+    'line-count-threshold-2': ['light cyan', ''],
+    'focused-line-count-threshold-2': ['light cyan,standout', ''],
+    'line-count-threshold-3': ['light blue', ''],
+    'focused-line-count-threshold-3': ['light blue,standout', ''],
+    'line-count-threshold-4': ['yellow', ''],
+    'focused-line-count-threshold-4': ['yellow,standout', ''],
+    'line-count-threshold-5': ['dark magenta', ''],
+    'focused-line-count-threshold-5': ['dark magenta,standout', ''],
+    'line-count-threshold-6': ['light magenta', ''],
+    'focused-line-count-threshold-6': ['light magenta,standout', ''],
+    'line-count-threshold-7': ['dark red', ''],
+    'focused-line-count-threshold-7': ['dark red,standout', ''],
+    'line-count-threshold-8': ['light red', ''],
+    'focused-line-count-threshold-8': ['light red,standout', ''],
     }
 
 # A delta from the default palette
