@@ -989,8 +989,7 @@ class CheckRevisionsTask(Task):
             for change in project.open_changes:
                 if repo:
                     for revision in change.revisions:
-                        if not (repo.hasCommit(revision.parent) and
-                                repo.hasCommit(revision.commit)):
+                        if repo.checkCommits([revision.parent, revision.commit]):
                             to_sync.add(change.id)
                 else:
                     to_sync.add(change.id)
@@ -1491,12 +1490,16 @@ class Sync(object):
         self.checkResponse(r)
         self.log.debug('Received: %s' % (r.text,))
         ret = None
+        if r.status_code > 400:
+            raise Exception("POST to %s failed with http code %s (%s)",
+                            path, r.status_code, r.text)
         if r.text and len(r.text)>4:
             try:
                 ret = json.loads(r.text[4:])
             except Exception:
                 self.log.exception("Unable to parse result %s from post to %s" %
                                    (r.text, url))
+                raise
         return ret
 
     def put(self, path, data):
