@@ -415,16 +415,16 @@ class ChangeMessageBox(mywid.HyperText):
         if message.author.username == self.app.config.username:
             name_style = 'change-message-own-name'
             header_style = 'change-message-own-header'
-            reviewer_string = message.author.name
+            reviewer_string = message.author_name
         else:
             name_style = 'change-message-name'
             header_style = 'change-message-header'
             if message.author.email:
                 reviewer_string = "%s <%s>" % (
-                    message.author.name,
+                    message.author_name,
                     message.author.email)
             else:
-                reviewer_string = message.author.name
+                reviewer_string = message.author_name
 
         text = [(name_style, reviewer_string),
                 (header_style, ': '+lines.pop(0)),
@@ -446,6 +446,29 @@ class ChangeMessageBox(mywid.HyperText):
         comment_text = ['\n'.join(lines)]
         for commentlink in self.app.config.commentlinks:
             comment_text = commentlink.run(self.app, comment_text)
+
+        inline_comments = {}
+        for file in message.revision.files:
+            comments = [c for c in file.comments
+                        if c.author.id == message.author.id
+                        and c.created == message.created]
+            for comment in comments:
+                path = comment.file.path
+                inline_comments.setdefault(path, [])
+                inline_comments[path].append((comment.line or 0, comment.message))
+        for v in inline_comments.values():
+            v.sort()
+
+        if inline_comments:
+            comment_text.append(u'\n')
+        for key, value in inline_comments.items():
+            comment_text.append(('filename-inline-comment', u'%s' % key))
+            for line, comment in value:
+                if not line:
+                    comment_text.append(u'\n  %s\n' % comment)
+                else:
+                    comment_text.append(u'\n  %s: %s\n' % (line, comment))
+
         self.set_text(text+comment_text)
 
 class CommitMessageBox(mywid.HyperText):
@@ -591,18 +614,17 @@ class ChangeView(urwid.WidgetWrap):
         missing_revisions = set()
         change_number = None
         change_id = None
+        shas = set()
         with self.app.db.getSession() as session:
             change = session.getChange(self.change_key)
+            change_project_name = change.project.name
             change_number = change.number
             change_id = change.id
-            repo = gitrepo.get_repo(change.project.name, self.app.config)
             for revision in change.revisions:
-                if not repo.hasCommit(revision.parent):
-                    missing_revisions.add(revision.parent)
-                if not repo.hasCommit(revision.commit):
-                    missing_revisions.add(revision.commit)
-                if missing_revisions:
-                    break
+                shas.add(revision.parent)
+                shas.add(revision.commit)
+        repo = gitrepo.get_repo(change_project_name, self.app.config)
+        missing_revisions = repo.checkCommits(shas)
         if missing_revisions:
             if self.app.sync.offline:
                 raise gertty.view.DisplayError("Git commits not present in local repository")
@@ -682,13 +704,13 @@ class ChangeView(urwid.WidgetWrap):
                 approval_headers.append(urwid.Text(('table-header', label.category)))
                 categories.append(label.category)
             votes = mywid.Table(approval_headers)
-            approvals_for_name = {}
+            approvals_for_account = {}
             pending_message = change.revisions[-1].getPendingMessage()
             for approval in change.approvals:
                 # Don't display draft approvals unless they are pending-upload
                 if approval.draft and not pending_message:
                     continue
-                approvals = approvals_for_name.get(approval.reviewer.name)
+                approvals = approvals_for_account.get(approval.reviewer.id)
                 if not approvals:
                     approvals = {}
                     row = []
@@ -696,12 +718,12 @@ class ChangeView(urwid.WidgetWrap):
                         style = 'reviewer-own-name'
                     else:
                         style = 'reviewer-name'
-                    row.append(urwid.Text((style, approval.reviewer.name)))
+                    row.append(urwid.Text((style, approval.reviewer_name)))
                     for i, category in enumerate(categories):
                         w = urwid.Text(u'', align=urwid.CENTER)
                         approvals[category] = w
                         row.append(w)
-                    approvals_for_name[approval.reviewer.name] = approvals
+                    approvals_for_account[approval.reviewer.id] = approvals
                     votes.addRow(row)
                 if str(approval.value) != '0':
                     cat_min, cat_max = change.getMinMaxPermittedForCategory(approval.category)
@@ -840,13 +862,16 @@ class ChangeView(urwid.WidgetWrap):
         # Handle depends-on
         parents = {}
         parent = session.getRevisionByCommit(revision.parent)
-        if parent and parent.change.status != 'MERGED':
+        if parent:
             subject = parent.change.subject
+            show_merged = False
             if parent != parent.change.revisions[-1]:
                 subject += ' [OUTDATED]'
+                show_merged = True
             if parent.change.status == 'ABANDONED':
                 subject += ' [ABANDONED]'
-            parents[parent.change.key] = subject
+            if show_merged or parent.change.status != 'MERGED':
+                parents[parent.change.key] = subject
         self._updateDependenciesWidget(parents,
                                        self.depends_on, self.depends_on_rows,
                                        header='Depends on:')
@@ -1156,8 +1181,9 @@ class ChangeView(urwid.WidgetWrap):
         self.app.log.debug("Reviewkey %s with approvals %s" %
                            (reviewkey['key'], approvals))
         row = self.revision_rows[self.last_revision_key]
+        message = reviewkey.get('message', '')
         submit = reviewkey.get('submit', False)
-        self.saveReview(row.revision_key, approvals, '', True, submit)
+        self.saveReview(row.revision_key, approvals, message, True, submit)
 
     def saveReview(self, revision_key, approvals, message, upload, submit):
         message_keys = self.app.saveReviews([revision_key], approvals,
@@ -1167,3 +1193,5 @@ class ChangeView(urwid.WidgetWrap):
                 self.app.sync.submitTask(
                     sync.UploadReviewTask(message_key, sync.HIGH_PRIORITY))
         self.refresh()
+        if self.app.config.close_change_on_review:
+            self.app.backScreen()
