@@ -170,7 +170,11 @@ class BaseDiffView(urwid.WidgetWrap, mywid.Searchable):
     def help(self):
         key = self.app.config.keymap.formatKeys
         commands = self.getCommands()
-        return [(c[0], key(c[0]), c[1]) for c in commands]
+        ret = [(c[0], key(c[0]), c[1]) for c in commands]
+        for k in self.app.config.reviewkeys.values():
+            action = ', '.join(['{category}:{value}'.format(**a) for a in k['approvals']])
+            ret.append(('', keymap.formatKey(k['key']), action))
+        return ret
 
     def __init__(self, app, new_revision_key):
         super(BaseDiffView, self).__init__(urwid.Pile([]))
@@ -324,11 +328,13 @@ class BaseDiffView(urwid.WidgetWrap, mywid.Searchable):
         # Handle comments that landed outside our default diff context
         lastlen = 0
         while comment_lists:
-            if len(comment_lists.keys()) == lastlen:
+            comment_lists_keys = list(comment_lists.keys())
+            if len(comment_lists_keys) == lastlen:
                 self.log.error("Unable to display all comments: %s" % comment_lists)
                 return
-            lastlen = len(comment_lists.keys())
-            key = comment_lists.keys()[0]
+            comment_lists_keys = list(comment_lists.keys())
+            lastlen = len(comment_lists_keys)
+            key = comment_lists_keys[0]
             kind, lineno, path = key.split('-', 2)
             lineno = int(lineno)
             if kind.startswith('old'):
@@ -469,6 +475,9 @@ class BaseDiffView(urwid.WidgetWrap, mywid.Searchable):
         if keymap.INTERACTIVE_SEARCH in commands:
             self.searchStart()
             return None
+        if key in self.app.config.reviewkeys:
+            self.reviewKey(self.app.config.reviewkeys[key])
+            return None
         return key
 
     def mouse_event(self, size, event, button, x, y, focus):
@@ -510,15 +519,21 @@ class BaseDiffView(urwid.WidgetWrap, mywid.Searchable):
         if file_key is None:
             raise Exception("Comment is not associated with a file")
         with self.app.db.getSession() as session:
-            fileojb = session.getFile(file_key)
+            fileobj = session.getFile(file_key)
             account = session.getAccountByUsername(self.app.config.username)
-            comment = fileojb.createComment(None, account, None,
+            comment = fileobj.createComment(None, account, None,
                                             datetime.datetime.utcnow(),
                                             parent,
                                             line_num, text, draft=True)
             key = comment.key
         return key
 
+    def reviewKey(self, reviewkey):
+        change_view = self.app.getPreviousScreen()
+        if change_view:
+            change_view.reviewKey(reviewkey)
+        self.app.backScreen()
+
     def openPatchsetDialog(self):
         revisions = []
         with self.app.db.getSession() as session:
